@@ -30,7 +30,6 @@ import socket
 import uuid
 
 from datetime import datetime
-from pprint import pp
 from periodic import Periodic
 
 
@@ -347,7 +346,6 @@ class HydraPy:
         for entries in ids:
             for entry in entries:
                 if len(entry) != 0:
-                    pp(entry)
                     instance_id = entry.split(':')[3]
                     trans.append(tr.hget(f'{self._redis_pre_key}:nodes', instance_id))
         await tr.execute()
@@ -511,8 +509,6 @@ class HydraPy:
             await self._health_check_event()
         if self._queue_handler:
             await self._queue_handler()
-        await asyncio.sleep(self._ONE_SECOND)
-        await self._hydra_events()
 
     async def init(self):
         self._instance_id = uuid.uuid4().hex
@@ -528,6 +524,7 @@ class HydraPy:
         # TODO: determine best way to close
         # self._redis.close()
         # await self._redis.wait_closed()
+
         return self.get_service_info()
 
     async def run(self):
